explabox.ingestibles 
=====================

.. automodule:: explabox.ingestibles
   :members:
   :undoc-members:
   :show-inheritance:

*Subpackages*:

.. toctree::
   :maxdepth: 4

   explabox.ingestibles.data
   explabox.ingestibles.model
